==> PyMunin-0.9.14.tar.gz: PyMunin-0.9.14/pymunin/plugins/phpfpmstats.py <==
#!/usr/bin/env python
"""phpfpmstats - Munin Plugin for monitoring PHP FPM (Fast Process Manager).

Requirements
  - The PHP FPM status page must be configured and it must have access 
    permissions from localhost.


Wild Card Plugin - No


Multigraph Plugin - Graph Structure
   - php_fpm_connections
   - php_fpm_processes
   
Environment Variables

  host:           Web Server Host. (Default: 127.0.0.1)
  port:           Web Server Port. (Default: 80, SSL: 443)
  user:           User in case authentication is required for access to 
                  FPM Status page.
  password:       Password in case authentication is required for access to 
                  FPM Status page.
  monpath:        FPM status page path relative to Document Root.
                  (Default: fpm_status.php)
  ssl:            Use SSL if yes. (Default: no)
  include_graphs: Comma separated list of enabled graphs. 
                  (All graphs enabled by default.)
  exclude_graphs: Comma separated list of disabled graphs.

  Example:
    [phpfpmstats]
        env.exclude_graphs php_fpm_processes

"""
# Munin  - Magic Markers
#%# family=auto
#%# capabilities=autoconf nosuggest

import sys
from pymunin import MuninGraph, MuninPlugin, muninMain
from pysysinfo.phpfpm import PHPfpmInfo

__author__ = "Ali Onur Uyar"
__copyright__ = "Copyright 2011, Ali Onur Uyar"
__credits__ = []
__license__ = "GPL"
__version__ = "0.8"
__maintainer__ = "Ali Onur Uyar"
__email__ = "aouyar at gmail.com"
__status__ = "Development"


class MuninPHPfpmPlugin(MuninPlugin):
    """Multigraph Munin Plugin for monitoring PHP Fast Process Manager (FPM).

    """
    plugin_name = 'phpfpmstats'
    isMultigraph = True

    def __init__(self, argv=(), env={}, debug=False):
        """Populate Munin Plugin with MuninGraph instances.
        
        @param argv:  List of command line arguments.
        @param env:   Dictionary of environment variables.
        @param debug: Print debugging messages if True. (Default: False)
        
        """
        MuninPlugin.__init__(self, argv, env, debug)
        
        self._host = self.envGet('host')
        self._port = self.envGet('port', None, int)
        self._user = self.envGet('user')
        self._monpath = self.envGet('monpath')
        self._password = self.envGet('password')
        self._ssl = self.envCheckFlag('ssl', False) 
        
        if self.graphEnabled('php_fpm_connections'):
            graph = MuninGraph('PHP FPM - Connections per second', 'PHP',
                info='PHP Fast Process Manager (FPM) - Connections per second.',
                args='--base 1000 --lower-limit 0')
            graph.addField('conn', 'conn', draw='LINE2', type='DERIVE', min=0)
            self.appendGraph('php_fpm_connections', graph)
        
        if self.graphEnabled('php_fpm_processes'):
            graph = MuninGraph('PHP FPM - Processes', 'PHP',
                info='PHP Fast Process Manager (FPM) - Active / Idle Processes.',
                args='--base 1000 --lower-limit 0')
            graph.addField('active', 'active', draw='AREASTACK', type='GAUGE')
            graph.addField('idle', 'idle', draw='AREASTACK', type='GAUGE')
            graph.addField('total', 'total', draw='LINE2', type='GAUGE',
                           colour='000000')
            self.appendGraph('php_fpm_processes', graph)
        
        
    def retrieveVals(self):
        """Retrieve values for graphs."""
        fpminfo = PHPfpmInfo(self._host, self._port, self._user, self._password, 
                             self._monpath, self._ssl)
        stats = fpminfo.getStats()
        if self.hasGraph('php_fpm_connections') and stats: 
            self.setGraphVal('php_fpm_connections', 'conn', 
                             stats['accepted conn'])
        if self.hasGraph('php_fpm_processes') and stats: 
            self.setGraphVal('php_fpm_processes', 'active', 
                             stats['active processes'])
            self.setGraphVal('php_fpm_processes', 'idle', 
                             stats['idle processes'])
            self.setGraphVal('php_fpm_processes', 'total', 
                             stats['total processes'])
    
    def autoconf(self):
        """Implements Munin Plugin Auto-Configuration Option.
        
        @return: True if plugin can be  auto-configured, False otherwise.
                 
        """
        fpminfo = PHPfpmInfo(self._host, self._port, self._user, self._password, 
                             self._monpath, self._ssl)
        return fpminfo is not None


def main():
    sys.exit(muninMain(MuninPHPfpmPlugin))
        
       
if __name__ == "__main__":
    main()

==> PyMunin-0.9.20.tar.gz: PyMunin-0.9.20/pymunin/plugins/phpfpmstats.py <==
#!/usr/bin/env python
"""phpfpmstats - Munin Plugin for monitoring PHP FPM (Fast Process Manager).

Requirements
  - The PHP FPM status page must be configured and it must have access 
    permissions from localhost.


Wild Card Plugin - No


Multigraph Plugin - Graph Structure
   - php_fpm_connections
   - php_fpm_processes
   
Environment Variables

  host:           Web Server Host. (Default: 127.0.0.1)
  port:           Web Server Port. (Default: 80, SSL: 443)
  user:           User in case authentication is required for access to 
                  FPM Status page.
  password:       Password in case authentication is required for access to 
                  FPM Status page.
  monpath:        FPM status page path relative to Document Root.
                  (Default: fpm_status.php)
  ssl:            Use SSL if yes. (Default: no)
  include_graphs: Comma separated list of enabled graphs. 
                  (All graphs enabled by default.)
  exclude_graphs: Comma separated list of disabled graphs.

Environment Variables for Multiple Instances of Plugin (Omitted by default.)
  instance_name:         Name of instance.
  instance_label:        Graph title label for instance.
                         (Default is the same as instance name.)
  instance_label_format: One of the following values:
                         - suffix (Default)
                         - prefix
                         - none 

  Example:
    [phpfpmstats]
        env.exclude_graphs php_fpm_processes

"""
# Munin  - Magic Markers
#%# family=auto
#%# capabilities=autoconf nosuggest

import sys
from pymunin import MuninGraph, MuninPlugin, muninMain
from pysysinfo.phpfpm import PHPfpmInfo

__author__ = "Ali Onur Uyar"
__copyright__ = "Copyright 2011, Ali Onur Uyar"
__credits__ = []
__license__ = "GPL"
__version__ = "0.9.20"
__maintainer__ = "Ali Onur Uyar"
__email__ = "aouyar at gmail.com"
__status__ = "Development"


class MuninPHPfpmPlugin(MuninPlugin):
    """Multigraph Munin Plugin for monitoring PHP Fast Process Manager (FPM).

    """
    plugin_name = 'phpfpmstats'
    isMultigraph = True
    isMultiInstance = True

    def __init__(self, argv=(), env=None, debug=False):
        """Populate Munin Plugin with MuninGraph instances.
        
        @param argv:  List of command line arguments.
        @param env:   Dictionary of environment variables.
        @param debug: Print debugging messages if True. (Default: False)
        
        """
        MuninPlugin.__init__(self, argv, env, debug)
        
        self._host = self.envGet('host')
        self._port = self.envGet('port', None, int)
        self._user = self.envGet('user')
        self._monpath = self.envGet('monpath')
        self._password = self.envGet('password')
        self._ssl = self.envCheckFlag('ssl', False)
        self._category = 'PHP'
        
        if self.graphEnabled('php_fpm_connections'):
            graph = MuninGraph('PHP FPM - Connections per second', self._category,
                info='PHP Fast Process Manager (FPM) - Connections per second.',
                args='--base 1000 --lower-limit 0')
            graph.addField('conn', 'conn', draw='LINE2', type='DERIVE', min=0)
            self.appendGraph('php_fpm_connections', graph)
        
        if self.graphEnabled('php_fpm_processes'):
            graph = MuninGraph('PHP FPM - Processes', self._category,
                info='PHP Fast Process Manager (FPM) - Active / Idle Processes.',
                args='--base 1000 --lower-limit 0')
            graph.addField('active', 'active', draw='AREASTACK', type='GAUGE')
            graph.addField('idle', 'idle', draw='AREASTACK', type='GAUGE')
            graph.addField('total', 'total', draw='LINE2', type='GAUGE',
                           colour='000000')
            self.appendGraph('php_fpm_processes', graph)
        
        
    def retrieveVals(self):
        """Retrieve values for graphs."""
        fpminfo = PHPfpmInfo(self._host, self._port, self._user, self._password, 
                             self._monpath, self._ssl)
        stats = fpminfo.getStats()
        if self.hasGraph('php_fpm_connections') and stats: 
            self.setGraphVal('php_fpm_connections', 'conn', 
                             stats['accepted conn'])
        if self.hasGraph('php_fpm_processes') and stats: 
            self.setGraphVal('php_fpm_processes', 'active', 
                             stats['active processes'])
            self.setGraphVal('php_fpm_processes', 'idle', 
                             stats['idle processes'])
            self.setGraphVal('php_fpm_processes', 'total', 
                             stats['total processes'])
    
    def autoconf(self):
        """Implements Munin Plugin Auto-Configuration Option.
        
        @return: True if plugin can be  auto-configured, False otherwise.
                 
        """
        fpminfo = PHPfpmInfo(self._host, self._port, self._user, self._password, 
                             self._monpath, self._ssl)
        return fpminfo is not None


def main():
    sys.exit(muninMain(MuninPHPfpmPlugin))
        
       
if __name__ == "__main__":
    main()
